function varargout=apogee(fname)
% [t,d,h]=apogee(fname)
%
% Load APOGEE data and returns it
%
% INPUT:
% 
% fname   A filename string
% 
% OUTPUT:
%
% t       A datetime variable
% d       The data from the file
% h       The header from the data
%
% Last modified by fjsimons-at-alum.mit.edu, 10/18/2022

fid=fopen(fname,'r');
% Read the header
h=fgetl(fid);
% Read the data which come in the format
% Oct 18 2022 at 10:32:53 AM, 28.294
% v=textscan(fid,'%s%d%d%s%d:%d:%d%s%f');

% Read the data which come in the format
% Oct 18 2022 at 11:33:02 AM, 667.403, 138.093, 0.207
v=textscan(fid,'%s%d%d%s%d:%d:%d%s%f,%f,%f');
fclose(fid);

% Pick out numeric month assuming the first applies
mon=month(sprintf('01-%s-2022',cell2mat(v{1}(1,:))));

% Turn the dates into datetime format 
t=datetime(v{3},10,v{2},v{5},v{6},v{7});

% And turn the data into simple columns
try
    d=[v{9} v{10} v{11}];
catch
    try
        d=[v{9} v{10}];
    catch
        d=[v{9}];
    end
end

% Optional output
varns={t,d,h};
varargout=varns(1:nargout);
