%% Load data
clear
clf
n1 = [50 52 27 54 4 11]; %tree number
n2 = [1 3 5 7 9 11]; %row/transect number
n = length(n1); %number of files

lengthsa = [1:n]; %lengths array made

albedostruct = {}; %create a structure to store uneven arrays

for i = 1:n
    [t,d,h]=apogee(sprintf('o2_albedoleaves_t%d%s%d.csv', n1(i), 'r', n2(i))); %file with albedo of a pile of leaves at trees
    albedos = d(:,3); 
    l = length(albedos);

    %store
    albedostruct{i} = albedos; %albedo values
    lengthsa(i) = l; %lengths
end

maxlengths = max(lengthsa); %max lengths
bigmatrix = NaN(maxlengths, n); %make an empty matrix of NaN to store info later

%add NaNs to shorter files to make them equal
for i = 1:n
    numnans = maxlengths - lengthsa(i); 
    a = albedostruct{i};
    a(lengthsa(i)+1:lengthsa(i)+numnans) = NaN;
    bigmatrix(:,i) = a;
end

%do a boxplot for each surface
boxplot(bigmatrix) % 'BoxStyle','filled')
xlab = {sprintf('Tree %d',n1(1)),sprintf('Tree %d',n1(2)),sprintf('Tree %d',n1(3)),sprintf('Tree %d',n1(4)),sprintf('Tree %d',n1(5)),sprintf('Tree %d',n1(6))};
xticklabels(xlab)

%edit features
h = findobj('LineStyle','--'); set(h, 'LineStyle','-'); %Get handles for outlier lines.
g = findobj(gca,'tag','Outliers'); set(g,'Marker','.','Color','#FF8800', 'MarkerSize',10); % Change symbols for all the groups.

%general chart information (titles)
ylabel('Albedos')
xlabel('Leaves of trees at rows 1, 3, 5, 7, 9, 11')

set(gca,'FontSize',16)
exportgraphics(figure(1),'o2_albedoleaves_boxplot.pdf')