%% Load data
clear
clf
n = 25; %number of files

lengthsa = [1:n]; %lengths array made

albedostruct = {}; %create a structure to store uneven arrays

filenames = ["o2_albedoleaves_t5_sun.csv" "o2_albedoleaves_t5_shade.csv" "o2_albedodryleaves_t5_sun.csv" "o2_albedodryleaves_t5_shade.csv" "o2_albedoolivebark_sun.csv" "o2_albedoolivebark_shade.csv" "o2_albedoartemisia_sun.csv" "o2_albedoartemisia_shade.csv" "o2_albedocommonfig_sun.csv" "o2_albedocommonfig_shade.csv" "o2_albedoholmoak_sun.csv" "o2_albedoholmoak_shade.csv" "o2_albedoyellowpricklypears_sun.csv" "o2_albedoyellowpricklypears_shade.csv" "o2_albedolightgreenpricklypears_sun.csv" "o2_albedo_lightgreenpricklypears_shade.csv" "o2_albedodarkgreenpricklypears_sun.csv" "o2_albedodarkgreenpricklypears_shade.csv" "o2_albedostraw_sun.csv" "o2_albedostraw_shade.csv" "o2_albedogranite_sun.csv" "o2_albedogranite_shade.csv" "o2_albedolichenedgranite_sun.csv" "o2_albedosoilhillside_sun.csv" "o2_albedosoilpebbleshillside_sun.csv"];

for i = 1:n
    filename = filenames(1,i); %find file
    [t,d,h]=apogee(filename); 
    albedos = d(:,3); 
    l = length(albedos);

    %store
    albedostruct{i} = albedos; %albedo values
    lengthsa(i) = l; %lengths
end

maxlengths = max(lengthsa); %max lengths
bigmatrix = NaN(maxlengths, n); %make an empty matrix of NaN to store info later

%add NaNs to shorter files to make them equal

for i = 1:n
    numnans = maxlengths - lengthsa(i); 
    a = albedostruct{i};
    a(lengthsa(i)+1:lengthsa(i)+numnans) = NaN;
    bigmatrix(:,i) = a;
end

%do a boxplot for each surface
boxplot(bigmatrix) % 'BoxStyle','filled')
xlab = {"tree 5 leaves (sun)", 'tree 5 leaves (shade)', 'tree 5 dead leaves (sun)', 'tree 5 dead leaves (shade)', 'olive tree bark (sun)', 'olive tree bark (shade)','artemisia campestris (sun)', 'artemisia campestris (shade)', 'common fig (sun)', 'common fig (shade)', 'holm oak leaves(sun)', 'holm oak leaves (shade)', 'yellow prickly pear (sun)', 'yellow prickly pear (shade)', 'light green prickly pear (sun)', 'light green prickly pear (shade)', 'dark green prickly pear (sun)', 'dark green prickly pear (shade)', 'straw (sun)', 'straw (shade)', 'granite (sun)', 'granite (shade)', 'lickened granite (sun)', 'hillside soil (sun)', 'hillside pebbles and untouched soil'};

xticklabels(xlab)

%edit features
h = findobj('LineStyle','--'); set(h, 'LineStyle','-'); %Get handles for outlier lines.
g = findobj(gca,'tag','Outliers');
set(g,'Marker','.','Color','#FF8800', 'MarkerSize',10); % Change symbols for all the groups.

%titles
title('Enotre')
xlabel('Surface Types')
ylabel('Albedos')

set(gca, 'FontSize',12); % Change font size
exportgraphics(figure(1), "o2_albedosurface_boxplots.pdf")

