%% Load data
clear
clf
n = 8; %number of files

lengthsa = [1:n]; %lengths array made

albedostruct = {}; %create a structure to store uneven arrays

for i = 1:n
    filename = sprintf('albedoleaves_t%d.csv', i); %find file
    [t,d,h]=apogee(filename); 
    albedos = d(:,3); 
    l = length(albedos);

    %store
    albedostruct{i} = albedos; %albedo values
    lengthsa(i) = l; %lengths
end

maxlengths = max(lengthsa); %max lengths
bigmatrix = NaN(maxlengths, n); %make an empty matrix of NaN to store info later

%add NaNs to shorter files to make them equal
for i = 1:n
    numnans = maxlengths - lengthsa(i); 
    a = albedostruct{i};
    a(lengthsa(i)+1:lengthsa(i)+numnans) = NaN;
    bigmatrix(:,i) = a;
end

%do a boxplot for each surface
boxplot(bigmatrix) % 'BoxStyle','filled')
xlab = {'t1', 't2', 't3', 't4', 't5', 't6', 't7', 't8'};
xticklabels(xlab)

%edit features
h = findobj('LineStyle','--'); set(h, 'LineStyle','-'); %Get handles for outlier lines.
g = findobj(gca,'tag','Outliers'); set(g,'Marker','.','Color','#FF8800', 'MarkerSize',10); % Change symbols for all the groups.

%general chart information (titles)
ylabel('Surface Types')
xlabel('Albedos')

set(gca,'FontSize',16)
exportgraphics(figure(1),'o1_albedoleaves_boxplot.pdf')