%% Load data
clear
clf
n = 12; %number of files

lengthsa = [1:n]; %lengths array made

albedostruct = {}; %create a structure to store uneven arrays

filenames = ["o1_albedograss_sun_trial1.csv" "o1_albedograss_shade_trial1.csv" "o1_albedograss_sun_trial2.csv" "o1_albedograss_shade_trial2.csv" "o1_albedoleaves_sun_trail1.csv" "o1_albedoleaves_shade_trial1.csv" "o1_albedoleaves_sun_trail2.csv" "o1_albedoleaves_shade_trial2.csv" "o1_mudpiles_sun_trial1.csv" "o1_mudpiles_shade_trial1.csv" "o1_mudpiles_sun_trial2.csv" "o1_mudpiles_shade_trial2.csv"];

for i = 1:n
    filename = filenames(1,i); %find file
    [t,d,h]=apogee(filename); 
    albedos = d(:,3); 
    l = length(albedos);

    %store
    albedostruct{i} = albedos; %albedo values
    lengthsa(i) = l; %lengths
end

maxlengths = max(lengthsa); %max lengths
bigmatrix = NaN(maxlengths, n); %make an empty matrix of NaN to store info later

%add NaNs to shorter files to make them equal
for i = 1:n
    numnans = maxlengths - lengthsa(i); 
    a = albedostruct{i};
    a(lengthsa(i)+1:lengthsa(i)+numnans) = NaN;
    bigmatrix(:,i) = a;
end

%do a boxplot for each surface
boxplot(bigmatrix) % 'BoxStyle','filled')
xlab = {'Grass (Sun): Low Battery', 'Grass (Shade): Low Battery', 'Grass (Sun): High Battery', 'Grass (Shade): High Battery', 'Leaves (Sun): Low Battery','Leaves (Shade): Low Battery','Leaves (Sun): High Battery','Leaves (Shade): High Battery', 'Mudpile (Sun): Surface', 'Mudpile (Shade): Surface','Mudpile (Sun): 6 in. Deep','Mudpile (Shade): 6 in. Deep'}; %albedometer high or low battery
xticklabels(xlab)

%edit features
h = findobj('LineStyle','--'); set(h, 'LineStyle','-'); %Get handles for outlier lines.
g = findobj(gca,'tag','Outliers');
set(g,'Marker','.','Color','#FF8800', 'MarkerSize',10); % Change symbols for all the groups.

%titles
title('Pino Giordana Surfaces')
xlabel('Surface Types')
ylabel('Albedos')

set(gca, 'FontSize',12); % Change font size
exportgraphics(figure(1), "o1_albedosurface_boxplots.pdf")

