%% Load data
clear
clf
n = 21; %number of files

lengthsa = [1:n]; %lengths array made

albedostruct = {}; %create a structure to store uneven arrays

filenames = ["o3_albedoleaves_t2_sun.csv" "o3_albedoleaves_t2_shade.csv" "o3_albedodeadleaves_t2_sun.csv" "o3_albedodeadleaves_t2_shade.csv" "o3_albedoleaves_t8_sun.csv" "o3_albedograss_sun.csv" "o3_albedograss_shade.csv" "o3_albedobaremudpile_sun.csv" "o3_albedobaremudpile_shade.csv" "o3_albedountouchedmudpile_sun.csv" "o3_albedountounchedmudpile_shade.csv" "o3_albedomudpiledug_sun.csv" "o3_albedomudpiledug_shade.csv" "o3_albedoborage_sun.csv" "o3_albedoborage_shade.csv" "o3_albedobroccoli_sun.csv" "o3_albedobroccoli_shade.csv" "o3_albedoturnip_sun.csv" "o3_albedoturnip_shade.csv" "o3_albedolettuce_sun.csv" "o3_albedolettuce_shade.csv"];

for i = 1:n
    filename = filenames(i); %find file
    [t,d,h]=apogee(filename); 
    albedos = d(:,3); 
    l = length(albedos);

    %store
    albedostruct{i} = albedos; %albedo values
    lengthsa(i) = l; %lengths
end

maxlengths = max(lengthsa); %max lengths
bigmatrix = NaN(maxlengths, n); %make an empty matrix of NaN to store info later

%add NaNs to shorter files to make them equal

for i = 1:n
    numnans = maxlengths - lengthsa(i); 
    a = albedostruct{i};
    a(lengthsa(i)+1:lengthsa(i)+numnans) = NaN;
    bigmatrix(:,i) = a;
end

%do a boxplot for each surface
boxplot(bigmatrix) % 'BoxStyle','filled')
xlab = {"tree 2 leaves (sun)", 'tree 2 leaves (shade)', 'tree 2 dead leaves (sun)', 'tree 2 dead leaves (shade)', 'tree 8 leaves (sun)', 'grass (sun)', 'grass (shade)', 'mudpile: bare (sun)', 'mudpile: bare (shade)', 'mudpile: untouched (sun)', 'mudpile: untouched (shade)', 'mudpile: dug 6 in. (sun)', 'mudpile: dug 6 in. (shade)', 'borage (sun)', 'borage (shade)', 'broccoli (sun)', 'broccoli (shade)','turnip (sun)', 'turnip (shade)', 'lettuce (sun)', 'lettuce (shade)'};

xticklabels(xlab)

%edit features
h = findobj('LineStyle','--'); set(h, 'LineStyle','-'); %Get handles for outlier lines.
g = findobj(gca,'tag','Outliers');
set(g,'Marker','.','Color','#FF8800', 'MarkerSize',10); % Change symbols for all the groups.

%titles
title('Santa Severina')
xlabel('Surface Types')
ylabel('Albedos')

set(gca, 'FontSize',12); % Change font size
exportgraphics(figure(1), "o3_albedosurface_boxplots.pdf")

